@@ -33,8 +33,8 @@ static const QMap<QString, QRegularExpression> s_shortcutWhitelist{
     {QStringLiteral("/component/mediacontrol"), QRegularExpression(QStringLiteral("stopmedia|nextmedia|previousmedia|playpausemedia"))},
     {QStringLiteral("/component/kmix"), QRegularExpression(QStringLiteral("mute|decrease_volume|increase_volume"))},
     {QStringLiteral("/component/org_kde_powerdevil"),
-     QRegularExpression(QStringLiteral(
-         "Increase Screen Brightness|Decrease Screen Brightness|Increase Keyboard Brightness|Decrease Keyboard Brightness|Turn Off Screen|Sleep|Hibernate"))},
+     QRegularExpression(QStringLiteral("Increase Screen Brightness|Decrease Screen Brightness|Increase Keyboard Brightness|Decrease Keyboard Brightness|Toggle "
+                                       "Keyboard Backlight|Turn Off Screen|Sleep|Hibernate"))},
     {QStringLiteral("/component/KDE_Keyboard_Layout_Switcher"),
      QRegularExpression(QStringLiteral("Switch to Next Keyboard Layout|Switch keyboard layout to .*"))},
     {QStringLiteral("/component/kcm_touchpad"), QRegularExpression(QStringLiteral("Toggle Touchpad|Enable Touchpad|Disable Touchpad"))},
